﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using GrapeCity.ActiveReports.Export.Pdf.Section;
using System.IO;
using GrapeCity.ActiveReports.Document;

namespace Ar_Silverlight.Web
{
    /// <summary>
    /// Summary description for Report
    /// </summary>
    public class Report : IHttpHandler
    {

        public void ProcessRequest(HttpContext context)
        {
            string id = context.Request.Params["id"];

            if (string.IsNullOrEmpty(id))
			{
                ThrowException(context.Response);
				return;
            }

            SectionDocument sd = ReportCache.GetSectionDocument(id);
            if (sd == null)
            {
                ThrowException(context.Response);
                return;
            }

            string type = context.Request.Params["type"];
            if (string.IsNullOrEmpty(type))
            {
                type = "rdf";
            }

            type = type.ToLower();
            switch (type)
            { 
                case "pdf":
                    PdfExport pdfExport = new PdfExport();
                    string print = context.Request.Params["print"];
                    if (print == null)
                    {
                        print = "false";
                    }

                    print = print.ToLower();
                    if (print != "false")
                    {
                        pdfExport.Options.OnlyForPrint = true;
                    }

                    using (var outStream = new MemoryStream())
                    {
                        // Put output into the stream
                        pdfExport.Export(sd, outStream);

                        // send the bits
                        context.Response.Clear();
                        context.Response.ContentType = "application/pdf";
                        context.Response.AddHeader("content-disposition", "inline; filename=ActiveReports.PDF");
                        context.Response.BinaryWrite(outStream.ToArray());
                    }
                    break;
                case "rdf":
                default:
                    using (MemoryStream outStream = new MemoryStream())
                    {
                        // Put output into the stream
                        sd.Save(outStream);

                        // send the bits
                        context.Response.Clear();
                        context.Response.BinaryWrite(outStream.ToArray());
                    }
                    break;
            }
        }

        private void ThrowException(HttpResponse response)
        {
            response.ContentType = "text/html";
            response.Write("<h1>The specified report was not found on the server.</h1>");
            response.Flush();
        }

        public bool IsReusable
        {
            get
            {
                return false;
            }
        }
    }
}